@@ -174,11 +174,6 @@ class BillPayments(Resource):
                         "amount": payload.get("amount", "")
                     })
 
-                # if 'reference' in payload.keys():
-                #     data.update({
-                #         "reference": payload.get("reference", "")
-                #     })
-
                 if 'date' in payload.keys():
                     data.update({
                         "date": payload.get("date", "")
@@ -188,9 +183,9 @@ class BillPayments(Resource):
 
                 for i in range(len(invoices)): 
                     if i == 0:
-                        if 'reference' in invoices[i].keys():
+                        if 'payment_reference' in invoices[i].keys():
                             data.update({
-                                "reference_number": invoices[i].pop('reference')
+                                "reference_number": invoices[i].pop('payment_reference')
                             })
                         if 'account_id' in invoices[i].keys():
                             data.update({
@@ -232,9 +227,9 @@ class BillPayments(Resource):
                         data.update({
                             "ownerInvoiceNumber": invoice[0].pop("invoice_id"),
                         }) 
-                    if 'reference' in invoice[0].keys():
+                    if 'payment_reference' in invoice[0].keys():
                         data.update({
-                            "paymentReference": invoice[0].pop('reference')
+                            "paymentReference": invoice[0].pop('payment_reference')
                         })
                     if 'amount' in invoice[0].keys():
                         data.update({
