@@ -404,6 +404,8 @@ class Payments(Resource):
                     "date": payload.get("date", ""),
                     "amount": int(float(payload.get("amount", 0))),
                     "partner_id": int(float(payload.get("customer_id", 0))),
+                    "currency_code": payload.get("currency_code", ""),
+                    "account_id": payload.get("account_id", ""),
                     # "payment_reference": payload.get("reference", ""),
                 }
 
